@@ -9,6 +9,7 @@ from maggma.api.query_operator import (
 
 from emmet.api.routes.materials.query_operators import FormulaQuery, ChemsysQuery
 from emmet.api.routes.oxidation_states.query_operators import PossibleOxiStateQuery
+from emmet.api.core.global_header import GlobalHeaderProcessor
 
 
 def oxi_states_resource(oxi_states_store):
@@ -25,6 +26,7 @@ def oxi_states_resource(oxi_states_store):
                 OxidationStateDoc, default_fields=["material_id", "last_updated"]
             ),
         ],
+        header_processor=GlobalHeaderProcessor(),
         tags=["Oxidation States"],
         disable_validation=True,
     )
